EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_AddLogEntry',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a log entry.'
GO

IF OBJECT_ID('[Executions_AddLogEntry]') IS NOT NULL DROP PROCEDURE [Executions_AddLogEntry]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_AddLogEntry]
(
	@Execution_Id INT,
	@Scope_Sequence INT,
	@LogEntry_Level INT,
	@LogEntry_Text VARBINARY(MAX),
	@LogEntry_Date DATETIME
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @LogEntry_Sequence INT
	SET @LogEntry_Sequence = COALESCE((SELECT MAX([LogEntry_Sequence])
	                                     FROM [ScopedExecutionLogEntries]
	                                     WITH (UPDLOCK)
	                                    WHERE [Execution_Id] = @Execution_Id), 0) + 1

	INSERT INTO [ScopedExecutionLogEntries]
	(
		[Execution_Id],
		[Scope_Sequence],
		[LogEntry_Sequence],
		[LogEntry_Level],
		[LogEntry_Text],
		[LogEntry_Date]
	)
	VALUES
	(
		@Execution_Id,
		@Scope_Sequence,
		@LogEntry_Sequence,
		@LogEntry_Level,
		@LogEntry_Text,
		@LogEntry_Date
	)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Executions_AddLogEntry] TO [ProGetUser_Role]
