EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NpmPackages_IncrementDownloadCount',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Increments the download count for an npm package.'
GO

IF OBJECT_ID('[NpmPackages_IncrementDownloadCount]') IS NOT NULL DROP PROCEDURE [NpmPackages_IncrementDownloadCount]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [NpmPackages_IncrementDownloadCount]
(
	@Feed_Id INT,
	@Package_Name NVARCHAR(200),
	@Scope_Name VARCHAR(200),
	@Version_Text VARCHAR(200)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE NPV
	   SET NPV.[Download_Count] = NPV.[Download_Count] + 1,
	       NPV.[LastDownloaded_Date] = GETUTCDATE()
	  FROM [NpmPackageVersions] NPV
	       INNER JOIN [NpmPackages] NP
		           ON NP.[Package_Id] = NPV.[Package_Id]
	 WHERE NP.[Feed_Id] = @Feed_Id
	   AND NP.[Package_Name] = @Package_Name
 	   AND NP.[Scope_Name] = @Scope_Name
	   AND NPV.[Version_Text] = @Version_Text

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [NpmPackages_IncrementDownloadCount] TO [ProGetUser_Role]
GO